@@ -8,17 +8,22 @@ class UserFactory(DjangoModelFactory):
 
     username = Faker("user_name")
     email = Faker("email")
+    first_name = Faker("first_name")
 
     @post_generation
     def password(self, create: bool, extracted: Sequence[Any], **kwargs):
-        password = Faker(
-            "password",
-            length=42,
-            special_chars=True,
-            digits=True,
-            upper_case=True,
-            lower_case=True,
-        ).generate(extra_kwargs={})
+        password = (
+            extracted
+            if extracted
+            else Faker(
+                "password",
+                length=42,
+                special_chars=True,
+                digits=True,
+                upper_case=True,
+                lower_case=True,
+            ).generate(extra_kwargs={})
+        )
         self.set_password(password)
 
     class Meta:
