@@ -468,7 +468,7 @@ REST_FRAMEWORK = {
 
 # django-project-backup
 SERIALIZATION_MODULES = {
-    'dbp_couchdb_datastore': 'django_project_backup.utils.couchdb.serializers'
+    'dpb_couchdb_datastore': 'django_project_backup.utils.couchdb.serializers'
 }
 
 DJANGO_PROJECT_BACKUP_MODE = env('DJANGO_PROJECT_BACKUP_MODE', default='incremental')
@@ -503,5 +503,10 @@ DJANGO_PROJECT_BACKUP_DO_FAILSAFE_BACKUP = env.bool('DJANGO_PROJECT_BACKUP_DO_FA
 DJANGO_PROJECT_BACKUP_FAILSAFE_BACKUP_PATH = env('DJANGO_PROJECT_BACKUP_FAILSAFE_BACKUP_PATH',
                                                  default=os.path.join(DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER, 'failed'))
 
+DJANGO_PROJECT_BACKUP_DO_REALTIME_COUCHDB_BACKUP = env.bool('DJANGO_PROJECT_BACKUP_DO_REALTIME_COUCHDB_BACKUP',
+                                                            default=DJANGO_PROJECT_BACKUP_REALTIME)
+DJANGO_PROJECT_BACKUP_DO_REALTIME_LOG_BACKUP = env.bool('DJANGO_PROJECT_BACKUP_DO_REALTIME_LOG_BACKUP',
+                                                        default=False)
+
 
 from .extra import *  # pai
