@@ -26,6 +26,7 @@ from ..permissions import is_authenticated
 from ..utils import set_session_key, get_session_key, get_random_fingerprint
 from .. import views as django_sso_app_views
 from .. import app_settings
+
 from .serializers import LoginSerializer, SignupSerializer, PasswordResetSerializer, PasswordResetFromKeySerializer, \
                          PasswordChangeSerializer, AddEmailSerializer, PasswordSetSerializer
 
@@ -156,7 +157,8 @@ class LoginView(DjangoSsoAppApiViewMixin, django_sso_app_views.LoginView):
 
                 raise Exception('Email not verified')
 
-        except:
+        except Exception as e:
+            logger.exception('Error: {}'.format(e))
             return self.get_error_response()
 
         else:
@@ -228,9 +230,9 @@ class SignupView(DjangoSsoAppApiViewMixin, django_sso_app_views.SignupView):
     serializer_class = SignupSerializer
     http_method_names = ['head', 'post', 'options']
     signup_form_fields = app_settings.USER_FIELDS + ('password1', 'password2',
-                                                              'fingerprint',
-                                                              'referer',
-                                                              'groups')
+                                                     'fingerprint',
+                                                     'referer',
+                                                     'groups')
 
     def get_form_kwargs(self, **kwargs):
         kwargs = super(SignupView, self).get_form_kwargs(**kwargs)
@@ -469,7 +471,6 @@ class PasswordSetView(DjangoSsoAppApiViewMixin, django_sso_app_views.PasswordSet
             response = Response(_('Password successfully set.'),
                             status=status.HTTP_200_OK)
 
-            adapter = get_adapter(request)
-            adapter.try_update_response_jwt(request.user, response)
+            self.update_response_jwt(request, response)
 
             return response
