@@ -191,14 +191,14 @@ def add_apigw_consumer_to_groups_acls(consumer_id, group_names):
     """
 
     for group_name in group_names:
-        status_code_2, acl = create_apigw_consumer_acl(consumer_id, group_name)
-        if status_code_2 != 201:
+        status_code, acl = create_apigw_consumer_acl(consumer_id, group_name)
+        if status_code not in (201, 409):  # 409 when already created
             logger.error(
                 'Error ({0}) creating apigw consumer acl, {1}'.format(
-                    status_code_2, acl))
+                    status_code, acl))
             raise Exception(
                 "Error {0} creating apigw consumer acl, {1}".format(
-                    status_code_2, acl))
+                    status_code, acl))
 
 
 # profile
