@@ -104,15 +104,10 @@ def api_gateway_signal_handler_when_profile_is_added_to_or_removed_from_group(ac
 
         if action == 'pre_add':
 
-            # do not create acl groups for signing up users
-            #if user.last_login is None:
-            #    logger.info('do not create acl groups while user never logged in')
-            #    return
-
             for pk in pk_set:
                 group = Group.objects.get(id=pk)
 
-                logger.info('creating api gateway acl group "{}" for profile "{}"'.format(group, profile))
+                logger.info('creating api gateway acl group "{}" for profile "{}"'.format(group.name, profile))
 
                 apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
                 status_code, resp = create_apigw_consumer_acl(apigateway_consumer_id, group.name)
@@ -121,9 +116,12 @@ def api_gateway_signal_handler_when_profile_is_added_to_or_removed_from_group(ac
                     logger.debug('api gateway acl group created {}, {}'.format(status_code, resp))
 
                     if not is_loaddata:  # or is_apigateway_update):
-                        profile.update_rev(True)
+                        if group.name != 'incomplete':
+                            profile.update_rev(True)
+
                 elif status_code == 409:
                     logger.debug('acl group "{} already created'.format(group.name))
+
                 else:
                     logger.exception('error ({}) creating api gateway acl group'.format(status_code))
 
@@ -139,8 +137,11 @@ def api_gateway_signal_handler_when_profile_is_added_to_or_removed_from_group(ac
                     logger.debug('"{}" DELETED, updating profile sso_rev'.format(group))
 
                     if not is_loaddata:
-                        profile.update_rev(True)
+                        if group.name != 'incomplete':
+                            profile.update_rev(True)
+
                 elif status_code == 404:
                     logger.debug('acl group "{} already deleted'.format(group.name))
+
                 else:
                     logger.exception('error ({}) deleting api gateway acl group'.format(status_code))
