@@ -9,6 +9,8 @@ from django.contrib.auth import get_user_model
 from django.db import transaction
 from django.utils import translation
 from django.conf import settings
+# http://ask.github.io/celery/cookbook/tasks.html#ensuring-a-task-is-only-executed-one-at-a-time
+from django.core.cache import cache
 
 from allauth.account.models import EmailAddress
 
@@ -20,6 +22,7 @@ from .utils import fetch_event_type_events, sort_event_type_events
 
 User = get_user_model()
 MODULE_NAME = 'events'
+LOCK_EXPIRE = 60 * 5 # Lock expires in 5 minutes
 
 
 # https://stackoverflow.com/questions/12414821/checking-a-nested-dictionary-using-a-dot-notation-string-a-b-c-d-e-automatica
@@ -130,6 +133,24 @@ def _create_users_by_events(logger):
 
 @shared_task(bind=True)
 def create_users_by_events(self, **kwargs):
-    _logger = kwargs.get('logger', get_task_logger('{}.{}'.format(MODULE_NAME, 'create_users_by_events')))
+    _name = 'create_users_by_events'
+    name = '{}.{}'.format(MODULE_NAME, _name)
+    _logger = get_task_logger(name)
 
-    return _create_users_by_events(_logger)
+    # The cache key consists of the module and task names
+    lock_id = '{}-lock'.format(name)
+
+    # cache.add fails if if the key already exists
+    acquire_lock = lambda: cache.add(lock_id, "true", LOCK_EXPIRE)
+    # memcache delete is very slow, but we have to use it to take
+    # advantage of using add() for atomic locking
+    release_lock = lambda: cache.delete(lock_id)
+
+    if acquire_lock():
+        try:
+            ret = _create_users_by_events(_logger)
+        finally:
+            release_lock()
+        return ret
+
+    _logger.debug("{} is already being executed by another worker".format(name))
