@@ -29,6 +29,7 @@ class ProfileSerializer(AbsoluteUrlSerializer):
     picture = serializers.CharField(required='picture' in app_settings.REQUIRED_PROFILE_FIELDS, allow_null=True)
     birthdate = serializers.DateField(required='birthdate' in app_settings.REQUIRED_PROFILE_FIELDS,
                                       allow_null=True)
+    country_of_birth = serializers.CharField(required='country_of_birth' in app_settings.REQUIRED_PROFILE_FIELDS)
 
     latitude = serializers.FloatField(required='latitude' in app_settings.REQUIRED_PROFILE_FIELDS)
     longitude = serializers.FloatField(required='longitude' in app_settings.REQUIRED_PROFILE_FIELDS)
@@ -42,7 +43,7 @@ class ProfileSerializer(AbsoluteUrlSerializer):
     alias = serializers.CharField(required='alias' in app_settings.REQUIRED_PROFILE_FIELDS,
                                   allow_null=True)
 
-    # role = serializers.IntegerField(required='role' in app_settings.REQUIRED_PROFILE_FIELDS)
+    gender = serializers.CharField(required='gender' in app_settings.REQUIRED_PROFILE_FIELDS)
 
     groups = serializers.SerializerMethodField(required=False)
 
@@ -52,6 +53,10 @@ class ProfileSerializer(AbsoluteUrlSerializer):
     required_fields = serializers.SerializerMethodField(required=False)
     completed_at = serializers.BooleanField(required=False)
 
+    company_name = serializers.CharField(required='company_name' in app_settings.REQUIRED_PROFILE_FIELDS)
+
+    # role = serializers.IntegerField(required='role' in app_settings.REQUIRED_PROFILE_FIELDS)
+
     class Meta:
         model = Profile
         read_only_fields = (
