@@ -1,7 +1,7 @@
 from django.conf.urls import url
 from rest_framework.urlpatterns import format_suffix_patterns
 
-from .views import ProfileApiViewSet, ProfileCompleteUnsubscriptionApiView, ProfileDetailApiView
+from .views import ProfileApiViewSet, ProfileDetailApiView
 
 
 _base_urlpatterns = [
@@ -11,12 +11,7 @@ _base_urlpatterns = [
         name="rest-detail"),
 ]
 
-_urlpatterns = _base_urlpatterns + [
-    # sso_id regexp can be either uuid or slug
-    url(r'^(?P<sso_id>[-_\w]+)/completely-unsubscribe/$',
-        ProfileCompleteUnsubscriptionApiView.as_view({'post': 'completely_unsubscribe'}),
-        name='rest-complete-unsubscription'),
-]
+_urlpatterns = _base_urlpatterns
 
 extra_urlpatterns = (format_suffix_patterns([
                          url(r'^profile/$', ProfileDetailApiView.as_view(), name="detail")]),
