@@ -59,7 +59,8 @@ class ProfileView(LoginRequiredMixin, WebpackBuiltTemplateViewMixin):
             raise
 
 
-class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateViewMixin):
+class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateViewMixin,
+                        DjangoSsoAppBaseViewMixin):
     model = Profile
     template_name = "account/profile_update.html"
     form_class = UserProfileForm
@@ -138,11 +139,12 @@ class ProfileApiViewSet(viewsets.ModelViewSet,
 
     def get_queryset(self):
         requesting_user = self.request.user
+        queryset = Profile.objects.filter(user__is_superuser=False, is_active=True, user__is_active=True)
 
         if is_staff(requesting_user):
-            return Profile.objects.all()
+            return queryset
         else:
-            return Profile.objects.filter(user=requesting_user)
+            return queryset.filter(user=requesting_user)
 
     def list(self, request, *args, **kwargs):
         """
@@ -182,7 +184,7 @@ class ProfileDetailApiView(generics.RetrieveAPIView):
     serializer_class = ProfileSerializer
 
     def get_queryset(self):
-        return Profile.objects.all()
+        return Profile.objects.filter(is_active=True, user__is_active=True)
 
     def get_object(self, *args, **kwargs):
         user = getattr(self.request, 'user', None)
