@@ -12,4 +12,6 @@ class UserFilter(filters.FilterSet):
             'username': ['exact'],
             'sso_app_profile__sso_id': ['exact'],
             'groups__name': ['exact'],
+            'date_joined': ['exact', 'gt', 'lt', 'gte', 'lte'],
+            'last_login': ['exact', 'gt', 'lt', 'gte', 'lte'],
         }
