@@ -116,14 +116,13 @@ class UserApiViewSet(mixins.ListModelMixin,
             return UserSerializer
 
     def get_queryset(self):
-        user = self.request.user
-        queryset = User.objects.filter(is_superuser=False, is_staff=False)
+        requesting_user = self.request.user
+        queryset = User.objects.filter(is_superuser=False, is_active=True)
 
-        if not is_staff(user):
-            profile = user.get_sso_app_profile()
-            queryset = queryset.filter(sso_app_profile__sso_id=profile.sso_id, is_active=True)
-
-        return queryset
+        if is_staff(requesting_user):
+            return queryset
+        else:
+            return queryset.filter(pk=requesting_user.pk)
 
     def get_object(self, *args, **kwargs):
         sso_id = self.kwargs.get('sso_id')
@@ -214,11 +213,9 @@ class UserDetailApiView(generics.RetrieveAPIView):
     User detail entrypoint
     """
 
+    queryset = User.objects.all()
     serializer_class = UserSerializer
 
-    def get_queryset(self):
-        return User.objects.all()
-
     def get_object(self, *args, **kwargs):
         user = getattr(self.request, 'user', None)
         return user
