@@ -2,8 +2,8 @@ import logging
 
 from allauth.account.auth_backends import AuthenticationBackend as allauth_AuthenticationBackend
 
+from ...utils import check_user_can_login
 from ...permissions import is_authenticated
-from ...utils import set_session_key
 
 logger = logging.getLogger('django_sso_app.core.authentication.backends')
 
@@ -12,9 +12,8 @@ class DjangoSsoAppLoginAuthenticationBackend(allauth_AuthenticationBackend):
     def authenticate(self, request, **credentials):
         user = super(DjangoSsoAppLoginAuthenticationBackend, self).authenticate(request, **credentials)
 
-        if is_authenticated(user):
-            logger.debug('"{}" is authenticated'.format(user))
+        if is_authenticated(request.user):
+            check_user_can_login(request.user,
+                                 skip_profile_completion_checks=True, skip_service_subscription_checks=True)
 
-            set_session_key(request, '__dssoa__requesting_user', user)
-
-            return user
+        return user
