@@ -24,6 +24,7 @@ class TestLogin(UserTestCase):
         new_user = self._get_new_user(password=new_pass)
 
         client = self._get_client()
+
         response = client.post(
             reverse('account_login'),
             data=self._get_login_object(new_user.email, new_pass)
@@ -68,7 +69,7 @@ class TestLogin(UserTestCase):
             data=self._get_login_object(new_admin_user.username, new_admin_pass)
         )
 
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_302_FOUND)
         self.assertIsNone(self._get_response_jwt_cookie(response), 'admin receives jwt')
 
     def test_django_staff_user_can_not_login_from_default_views(self):
@@ -80,8 +81,8 @@ class TestLogin(UserTestCase):
             reverse('account_login'),
             data=self._get_login_object(new_staff_user.username, new_staff_pass)
         )
-
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        print('RESP', response)
+        self.assertEqual(response.status_code, status.HTTP_302_FOUND)
         self.assertIsNone(self._get_response_jwt_cookie(response), 'staff receives jwt')
 
     def test_user_must_complete_profile(self):
@@ -137,6 +138,8 @@ class TestLogout(UserTestCase):
             data=self._get_login_object(new_user.email, new_pass)
         )
 
+        print('RE0,', response, response.status_code)
+
         self.assertEqual(response.status_code, status.HTTP_302_FOUND)
 
         user_devices_pre_logout = new_user.sso_app_profile.devices.all()
@@ -283,5 +286,7 @@ class TestSignup(UserTestCase):
         self._test_response_path(response, reverse('profile.complete'))
         self.assertIsNotNone(self._get_response_jwt_cookie(response), 'incomplete user do not receives jwt')
 
+        self.assertEqual(new_user.sso_app_profile.is_incomplete, True)
+
         self.assertIsNotNone(new_user.sso_app_profile.groups.filter(name='incomplete').first(),
                              'incomplete user did not enter "incomplete" group on login')
